@@ -18,7 +18,7 @@ def jsonify_success(data=None, msg=None, **kwargs):
 
 
 def jsonify_fail(code=0, msg=None, **kwargs):
-    return jsonify(False, code, msg,**kwargs)
+    return jsonify(False, code, msg, **kwargs)
 
 
 def jsonify(success=False, code=0, msg=None, data=None, **kwargs):
@@ -26,5 +26,6 @@ def jsonify(success=False, code=0, msg=None, data=None, **kwargs):
         if success:
             msg = "成功"
         else:
-            msg = Error_Code[code]
-    return jsonify_deity(success=success, code=code, msg=msg, data=data, **kwargs)
+            msg = Error_Code.get('code', '错误')
+    return jsonify_deity(success=success,
+                         code=code, msg=msg, data=data, **kwargs)
