@@ -16,12 +16,8 @@ def get_params(params=None):
                 for item in params.items():
                     value = g.params.get(item[0], None)
                     ForLog.show("参数", value)
-                    if value is None:
+                    if is_none_str(value):
                         return jsonify(success=False, msg=item[1], code='10001')
-                    if len(item) > 2:
-                        nullable = g.params.get(item[2], None)
-                        if nullable and is_none_str(value):
-                            return jsonify(success=False, msg=item[1], code='10001')
 
                     g.setdefault(item[0], value)
             return func(*args, **kwargs)
